Home Creators Posts Import Register Favorites Logout
haven't archived this post yet. have a subscription? use the importer!

Downloads

  • Ultra Skip - No Intro Movies v0.1.zip

Missing 1 file, as this post has not yet been imported.

Content

Happy Monday 😊

I've now moved this to Nexus with several updates. Lmk what you think!

https://www.nexusmods.com/silenthill2/mods/24

  • Copies some settings from Cinematic to the Epic quality so they're active in-game

  • Reduced black point slightly to glue the game together. Konami have used a slightly milky black, which I normally like but it doesn't work because of slight differences in texture brightnesses. Lowering the black point a smidge helps this a lot (you can still adjust overall brightness in-game)

  • Sped up disk streaming by enabling DirectX 12 PSO disk cache

  • Sped up lumen by a few fps

  • Reduced hair pixelation by increasing MSAA

  • Enabled separation between materials for subsurface scattering (doesn't look like there is SSS?)

  • Enabled iris mapping (if supported)

  • Enabled anisotropic filtering for virtual textures (it was completely disabled)

  • Increased anisotropic filtering from 8 to 16

  • Enabled light UE realtime texture sharpening

  • Switched from Kraken to Selkie texture compression (Kraken is a weird choice!)

  • Adjusted in-game graphics menu settings (Low, Mid, High, Epic) to better balance options

  • Increased temp CPU memory from 50MB to 2048MB

  • Corrected configuration bugs in DLSS and TSR

  • Forced DLSS preset C

  • Enabled Ultra Quality Plus in XeSS upscaler

  • Increased disk requests from 1MB to 16MB each (conservatively)

  • Increased streamer parallelism

  • Fixed a hitch by disabling up to 15ms additional frame time for loading

  • Fixed white flashes at edge of screen

  • Enabled IO dispatcher system (reduces resource cost)

  • Enabled the prestreamer system for smoother streaming

  • Fixed a hitch by disabling texture pre-tiling

  • Reduced virtual texture uploads from 8 per frame to 4 (expensive)

  • Enabled downsampled occlusion queries (faster, no quality reduction)

  • Added sphere bounding to frustum culls (faster, no quality reduction)

  • Increased lens flare quality at Epic setting

  • Increased bloom quality at Epic setting

  • Increased water reflection quality (non RT) at Epic setting

  • Disabled half resolution water refractions (they look awful)

  • Increased grass system parallelism to prevent hitches (if grass is used)

  • Disabled shader energy conservation which is for mobile platforms only

  • Disabled some debugging which was still active in the shipped game

  • Enabled saving of found user PSOs to disk for later caching

  • Fixed mip cache sizing (was '7', needs to be '14' for 4096x textures)

  • Enabled mesh streaming (it was completely disabled), otherwise meshes won't be built in time for textures and shaders, probably causing hitches

  • Fixed some pop-ins by increasing LOD and shadow fade time from 0.25s to 2s

  • Fixed a hitch by correcting shadow predraw resolution (it was enabled at full shadow resolution, so pointless)

  • Disabled unbuilt shadows to prevent them being drawn in game (expensive)

  • Possibly fixed fog jitter noise by increasing fog history weight to prevent jittering (might need to be increase it further)

  • Improved performance of fog by slightly reducing Z resolution from 128 voxels to 96 (expensive, no visual difference in UE)

  • Fixed a hitch by limiting shader batch time from 16ms per frame (!) to 1.5ms

  • Prevented particles from running on the RHI, they should only run on the game thread

Comments

No comments found for this post.